@@ -35,10 +35,19 @@ class Enviar(object):
     #FIXME: rever isso ao refatorar o sistema de pedido
     @property
     def valor_envio(self):
-        valor_total = self.pedido.valor_total or Decimal("0.00")
-        valor_subtotal = self.pedido.valor_subtotal or Decimal("0.00")
+        valor_envio = self.pedido.valor_envio or Decimal("0.00")
         valor_desconto = self.pedido.valor_desconto or Decimal("0.00")
-        return valor_total - valor_subtotal + valor_desconto
+        if valor_envio == valor_desconto:
+            return Decimal("0.00")
+        return valor_envio
+
+    @property
+    def valor_desconto(self):
+        valor_envio = self.pedido.valor_envio or Decimal("0.00")
+        valor_desconto = self.pedido.valor_desconto or Decimal("0.00")
+        if valor_envio == valor_desconto:
+            return Decimal("0.00")
+        return valor_desconto
 
 
 class EnviarPedido(Plugavel):
